@@ -4,10 +4,10 @@ from Cython.Build import cythonize
 import os
 
 
-def find_extensions(name):
+def find_extensions(name, setup_py):
     ex = []
-    prefix = os.path.split(__file__)[0]
-    dirname = os.path.join(os.path.split(__file__)[0], name)
+    prefix = os.path.split(setup_py)[0]
+    dirname = os.path.join(prefix, name)
     for root, subdirs, files in os.walk(dirname):
         if any(fname.endswith('.py') for fname in os.listdir(root)):
             path = root.replace(prefix + '/', "")
@@ -20,8 +20,8 @@ class build_py(build_py_orig):
         pass
 
 
-def artipy(dirname):
+def artipy(dirname, setup_py):
     return {
-        'ext_modules': cythonize(find_extensions(dirname)),
+        'ext_modules': cythonize(find_extensions(dirname, setup_py)),
         'cmdclass': {'build_py': build_py},
     }
